@@ -1,4 +1,4 @@
-# Copyright 2010 Ben Escoto
+# Copyright 2010 Benedict Escoto
 #
 # This file is part of FAViR.
 
@@ -15,11 +15,6 @@
 # You should have received a copy of the GNU General Public License
 # along with FAViR.  If not, see <http://www.gnu.org/licenses/>.
 
-################################################################
-# util.R - utility functions for the R actuarial example book
-
-################### Generic utility functions
-
 InitPaper <- function() {
   # Call this when starting a Sweave session
   .InitGraphDir()
@@ -37,11 +32,15 @@ kGraphDir <- "favir-graphs"
 FavirSweave <- function(filenames) {
   # Convert some sweave files into PDFs
   for (filename in filenames) {
-    Sweave(filename)
-    texi2dvi("hello-world.tex", pdf=TRUE)
+    Sweave(paste(filename, ".Rnw", sep=""))
+    texi2dvi(paste(filename, ".tex", sep=""), pdf=TRUE)
   }
 }
 
+
+################################################################
+# Generic utility functions
+
 OnError <- function() {
   # Print a stack trace and dump frames
   cat("----------------------------------------------------\n", file=stderr())
@@ -51,21 +50,14 @@ OnError <- function() {
     cat("    ", as.character(as.expression(trace.call)), "\n", sep="",
         file=stderr())
   }
-  cat("To examine the frame dump, run this R command:\n")
-  cat('    load("last.dump.rda"); debugger()\n')
+  cat("To examine the frame dump, run this R command:\n", file=stderr())
+  cat('    load("last.dump.rda"); debugger()\n', file=stderr())
   cat("----------------------------------------------------\n", file=stderr())
   dump.frames(to.file=TRUE)
 }
 
 Assert <- function(boolean, err.msg=NULL) {
   # Abort and display traceback and err.msg if boolean is false
-  #
-  # Args:
-  # boolean - TRUE or something other than TRUE
-  # err.msg - additional message to display if boolean is not TRUE
-  #
-  # Output: If boolean is TRUE, do nothing.  Otherwise display err.msg
-  # and print a traceback.
   if(isTRUE(boolean))
     return(invisible(NULL))
   call.list <- as.list(match.call())
@@ -81,8 +73,6 @@ Assert <- function(boolean, err.msg=NULL) {
 
 AssertSingle <- function(..., err.msg=NULL) {
   # Raise an error message if value does not have length 1
-  # This is just a short-cut for Assert(length(value) == 1) for each
-  # value in values.
   lengths <- sapply(list(...), length) # vector of lengths
   if(all(lengths == 1))
     return(NULL)
@@ -111,23 +101,6 @@ AssertSingle <- function(..., err.msg=NULL) {
   else return(split)
 }
 
-StrSplitOnce <- function(string, substring) {
-  # Split string into two pieces: before and after char
-  #
-  # Args: string and char as with SplitOn
-  #
-  # Output: a character vector of length 2, where the components are
-  # separated by char in the original string.  If there are multiple
-  # chars in the original, split after the first
-  split <- string %SplitOn% substring
-  len <- length(split)
-  if (len == 2)
-    return(split)
-
-  Assert(len >= 2, "Sanity check")
-  return(c(split[1], paste(split[2:len], collapse=substring)))
-}
-
 RowIndicies <- function(x) seq(length.out=nrow(x))
 
 Last <- function(x, n=1, allow.fewer=FALSE) {
@@ -211,9 +184,9 @@ with.favir.environment <- function(data, expr, ...) {
 
 
 ################################################################
-# latex.R - code for making pretty tables
+# Code for making pretty tables
 
-######### Color definitions and graphics defaults
+### definitions and graphics defaults
 # Three sets of colors in color scheme: labeled M (color main),
 # A (alternate A), and B (alternateB).  In each group, the
 # five colors are about the same hue and arranged from lightest to darkest
@@ -354,7 +327,7 @@ FieldHeadings <- function(fdf) {
 }
 
 `FieldHeadings<-` <- function(fdf, value) {
-  # Set the column formatting functions
+  # Set field headings in a favir.data.frame.
   Assert(all(names(value) %in% names(fdf)), "Heading specified for bad col")
   for (name in names(value))
     attributes(fdf)$favir.field.headings[name] <- value[name]
@@ -586,13 +559,6 @@ Label <- function(fdf) {
 
 SummaryRow <- function(fdf) {
   # Return the table's summary row
-  #
-  # The summary row is a row below the table set off by an hline that
-  # can hold totals or averages.
-  #
-  # Args: fdf - favir data frame to process
-  #
-  # Result: A list mapping data frame fields to summary row contents, or NULL
   return(attributes(fdf)$favir.summary.row)
 }
 
@@ -620,25 +586,11 @@ TextSize <- function(fdf) {
   return(fdf)
 }
 
-MatrixToFDF <- function(matrix, ..., rowname.col=NULL) {
-  # Convenience function: convert matrix in one step to favir data frame
-  #
-  # if row.name.col is not NULL, row names are added to the data frame
-  # under a separate name
-  df <- as.data.frame(matrix)
-  if (!is.null(rowname.col)) {
-    rowname.df <- data.frame(rownames(matrix))
-    names(rowname.df) <- rowname.col
-    df <- cbind(rowname.df, df)
-  }
-  return(FavirDF(df, ...))
-}
-
             
 ######### Latex code detail section - create latex from a favir df
 
-SplitHeadings <- function(char.vec, threshold=11, max.rows=3,
-                          split.char=" ") {
+.SplitHeadings <- function(char.vec, threshold=11, max.rows=3,
+                           split.char=" ") {
   # Split the character vector into multiple rows
   #
   # Input:
@@ -690,7 +642,7 @@ SplitHeadings <- function(char.vec, threshold=11, max.rows=3,
   return(result)
 }
 
-kTablePrefix1 <- "\\begin{figure}"
+kTablePrefix1 <- "\\begin{figure}[hbp]"
 kTablePrefix2 <- "
 \\begin{center}
 \\begin{tikzpicture}
@@ -707,7 +659,7 @@ kTableSuffix2 <- "\\end{center}\\end{figure}\n"
 kSidewaysTablePrefix1 <- "\\begin{sidewaysfigure}"
 kSidewaysTableSuffix2 <- "\\end{center}\\end{sidewaysfigure}\n"
 
-ColumnTypes <- function(data.matrix) {
+.ColumnTypes <- function(data.matrix) {
   # Return the latex column types for each column
   # Below, subtract 2 because of the math mode symbols $
   data.lengths <- apply(data.matrix, 2,
@@ -715,7 +667,7 @@ ColumnTypes <- function(data.matrix) {
   return(paste("D{!}{!}{", data.lengths, ".0}", sep=""))
 }
 
-PreLatex <- function(favir.df) {
+PreLatexFDF <- function(favir.df) {
   # Return a pre-latex version favir data frame 
   #
   # Args:
@@ -808,7 +760,7 @@ PreLatex <- function(favir.df) {
     for (i in seq(along=headings))
       if (headings[i] %in% names(FieldHeadings(favir.df)))
         headings[i] <- FieldHeadings(favir.df)[[headings[i]]]
-    return(SplitHeadings(headings))
+    return(.SplitHeadings(headings))
   }
 
   FormattedHeadings <- function(heading.matrix) {
@@ -869,7 +821,7 @@ PreLatex <- function(favir.df) {
   result$data.matrix <- DataMatrix()
   # extra data to be inserted before any data row
   result$extra.rows <- rep("", nrow(result$data.matrix))
-  result$column.types <- ColumnTypes(result$data.matrix)
+  result$column.types <- .ColumnTypes(result$data.matrix)
   result$caption <- paste("\\caption{", Caption(favir.df), "}",
                           collapse="", sep="")
   result$label <- paste("\\label{", Label(favir.df), "}",
@@ -957,7 +909,7 @@ RBindPreLatex <- function(..., include.headings=TRUE) {
                                        args[[i]]$data.matrix)
     result$data.row.prefixes <- c(result$data.row.prefixes,
                                   args[[i]]$data.row.prefixes)
-    result$column.types <- ColumnTypes(result$data.matrix)
+    result$column.types <- .ColumnTypes(result$data.matrix)
   }
   return(result)
 }
@@ -965,14 +917,14 @@ RBindPreLatex <- function(..., include.headings=TRUE) {
 print.favir.data.frame <- function(x, ...) {
   # Print a favir data frame
   Assert("favir.data.frame" %in% class(x))
-  return(invisible(print(PreLatex(x))))
+  return(invisible(print(PreLatexFDF(x))))
 }
 
 #######################################################################
 # Non-table related latex code
 
 IncludeGraph <- function(graph, caption="", label=NULL,
-                         width=5, height=5, filename=NULL) {
+                         width=12.5, height=12.5, filename=NULL) {
   # Write the graph to a PDF file and produce the latex to include the graph
   #
   # Arguments:
@@ -980,7 +932,7 @@ IncludeGraph <- function(graph, caption="", label=NULL,
   # filename - file to save plot to.  Otherwise derive name from graph
   # caption - the latex caption for the graph
   # label - the latex reference label for the graph
-  # width, height - dimensions in inches for the graph
+  # width, height - dimensions in centimeters for the graph
   #
   # Output: No return value, but create a PDF file on disk and print
   # latex code necessary to include PDF in a document.
@@ -1034,7 +986,7 @@ IncludeGrid <- function(graph.list, ...) {
 }
 
 .IncludeGraphHelper <- function(thunk, graph.name, filename=NULL, caption="",
-                                label=NULL, width=5, height=5) {
+                                label=NULL, width=12.5, height=12.5) {
   # Helper function for IncludeGraph and IncludeGrid
   AssertSingle(caption, width, height)
   if (is.null(filename)) { # Extract filename candidate from graph name
@@ -1042,18 +994,19 @@ IncludeGrid <- function(graph.list, ...) {
     prefix <- gsub(" ", "_", gsub(".", "_", graph.name, fixed=TRUE), fixed=TRUE)
     filename <- file.path(kGraphDir, paste(prefix, ".pdf", sep=""))
   }
-  pdf(file=filename, paper="special", width=width, height=height)
+  pdf(file=filename, paper="special",
+      width=width/2.54, height=height/2.54) # pdf() dims in inches
   thunk()
   dev.off()
   cat(paste("\\begin{figure}\\begin{center}\\includegraphics[width=",
-            width, "in,height=", height, "in]{",
+            width, "cm,height=", height, "cm]{",
             filename, "}\\caption{", caption, "}", sep=""))
   if (!is.null(label))
     cat(paste("\\label{", label, "}", sep=""))
   cat("\\end{center}\\end{figure}")
 }
 
-SetTheme <- function() {
+.SetTheme <- function() {
   # Set the theming parameters for ggplot2
   theme_update(panel.background=theme_rect(fill=favir.colors["M1"],
                                            colour=favir.colors["M1"]),
@@ -1071,10 +1024,11 @@ SetTheme <- function() {
   update_geom_defaults("bar", aes(colour=favir.colors["M3"],
                                   fill=favir.colors["M3"]))
 }
-SetTheme()
+.SetTheme()
 
 kPrelude1 <- ("\\documentclass[letterpaper,12pt]{article}
 \\usepackage[hmargin=1in,bmargin=1.5in,tmargin=1.2in]{geometry}
+\\usepackage{Sweave}
 \\usepackage{color}
 \\usepackage{booktabs}
 \\usepackage{colortbl}
@@ -1132,13 +1086,13 @@ kPrelude2 <- ("%%%%%%%%%%%%%%% End Colors, Start Logo
 \\pagestyle{fancy}
 \\renewcommand{\\headrule}{{\\color{colorM5}%
   \\hrule width\\headwidth height\\headrulewidth \\vskip-\\headrulewidth}}
-\\fancyfoot[LE]{\\vspace{0ex}\\favirlogo}
-\\fancyfoot[RO]{\\vspace{0ex}\\favirlogo\\hspace{2cm}}
-\\fancyfoot[CE,CO]{\\vspace{2.5ex}\\thepage}
+\\rfoot{\\favirlogo\\hspace{2cm}}
+\\cfoot{\\thepage}
 
 %%%%%%%%%%%%%%%% End Headers, Preamble
 
-\\begin{document}")
+\\begin{document}
+\\thispagestyle{plain}")
 
 IncludePrelude <- function(title, author, subtitle="") {
   # Insert the latex prelude into the document
@@ -1186,17 +1140,21 @@ See \\texttt{", kURL, "} for more information.\\\\ \\vspace{1em}}", sep="")
 
 IncludeLegal <- function(author, year) {
   # Return latex code for legal notice at the end of papers
-  copyright <- paste("Copyright \\copyright", year, author)
-  license <- paste("
-This paper is part of the FAViR project.  It and the R source code used to
-produce it are freely distributable under the GNU General Public
-License.  See \\textt{", kURL, "} for more information on
+  copyright <- paste("Copyright \\copyright \\hspace{0.7ex}", year, author)
+  source.license <- paste("
+This paper is part of the FAViR project.  All the R source code used
+to produce it is freely distributable under the GNU General Public
+License.  See \\texttt{", kURL, "} for more information on
 FAViR or to download the source code for this paper.", sep="")
+  gnu.permissive <- "
+Copying and distribution of this paper itself, with or without
+modification, are permitted in any medium without royalty provided the
+copyright notice and this notice are preserved.  This paper is offered
+as-is, without any warranty."
   vague.cya <- "
-No warranty, express or implied, is provided with this paper.  This paper
-is intended for educational purposes only and should not be used to
-violate anti-trust law.  The authors and FAViR editors do not necessarily
-endorse the information or techniques in this paper and assume no
-responsibility for their accuracy."
-  return(paste(copyright, license, vague.cya, sep="\n\n"))
+This paper is intended for educational purposes only and should not be
+used to violate anti-trust law.  The authors and FAViR editors do not
+necessarily endorse the information or techniques in this paper and
+assume no responsibility for their accuracy."
+  cat(paste(copyright, source.license, gnu.permissive, vague.cya, sep="\n\n"))
 }
